@@ -599,6 +599,8 @@ static inline char *ReplaceSpaceWithNewline(char **caption,char *space)
   size_t
     octets;
 
+  if ((caption == (char **) NULL) || (space == (char *) NULL))
+    return((char *) NULL);
   octets=(size_t) GetUTFOctets(space);
   if (octets == 1)
     *space='\n';
@@ -628,14 +630,14 @@ MagickExport ssize_t FormatMagickCaption(Image *image,DrawInfo *draw_info,
   const MagickBooleanType split,TypeMetric *metrics,char **caption,
   ExceptionInfo *exception)
 {
-  MagickBooleanType
-    status;
-
   char
     *p,
     *q,
     *s;
 
+  MagickBooleanType
+    status;
+
   size_t
     width;
 
@@ -791,7 +793,11 @@ MagickExport MagickBooleanType GetMultilineTypeMetrics(Image *image,
   assert(draw_info->text != (char *) NULL);
   assert(draw_info->signature == MagickCoreSignature);
   if (*draw_info->text == '\0')
-    return(MagickFalse);
+    {
+      (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
+        "LabelExpected","`%s'",image->filename);
+      return(MagickFalse);
+    }
   annotate_info=CloneDrawInfo((ImageInfo *) NULL,draw_info);
   annotate_info->text=DestroyString(annotate_info->text);
   /*
@@ -1014,7 +1020,7 @@ static MagickBooleanType RenderType(Image *image,const DrawInfo *draw_info,
   if ((type_info == (const TypeInfo *) NULL) &&
       (draw_info->family != (const char *) NULL))
     {
-      if (strstr(draw_info->family,",'\"") == (char *) NULL)
+      if (strpbrk(draw_info->family,",'\"") == (char *) NULL)
         type_info=GetTypeInfoByFamily(draw_info->family,draw_info->style,
           draw_info->stretch,draw_info->weight,exception);
       if (type_info == (const TypeInfo *) NULL)
@@ -1412,9 +1418,11 @@ static FT_Memory FreetypeAcquireMemoryManager()
   return(memory);
 }
 
-static void FreetypeDone(FT_Memory memory,FT_Library library)
+static void FreetypeDone(FT_Memory memory,FT_Library library,
+  FT_StreamRec *stream)
 {
   (void) FT_Done_Library(library);
+  stream=(FT_StreamRec *) RelinquishMagickMemory(stream);
   memory=(FT_Memory) RelinquishMagickMemory(memory);
 }
 
@@ -1584,7 +1592,8 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
           Extract face index, e.g. @msgothic[1].
         */
         ImageInfo *image_info = AcquireImageInfo();
-        (void) strcpy(image_info->filename,draw_info->font+1);
+        (void) CopyMagickString(image_info->filename,draw_info->font+1,
+          MagickPathExtent);
         (void) SetImageInfo(image_info,0,exception);
         face_index=(FT_Long) image_info->scene;
         args.pathname=ConstantString(image_info->filename);
@@ -1606,8 +1615,7 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
   ft_status=FT_Open_Face(library,&args,face_index,&face);
   if (ft_status != 0)
     {
-      stream=(FT_StreamRec *) RelinquishMagickMemory(stream);
-      FreetypeDone(memory,library);
+      FreetypeDone(memory,library,stream);
       ThrowFreetypeErrorException("UnableToReadFont",ft_status,args.pathname);
       args.pathname=DestroyString(args.pathname);
       return(MagickFalse);
@@ -1662,7 +1670,7 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
       if (ft_status != 0)
         {
           (void) FT_Done_Face(face);
-          FreetypeDone(memory,library);
+          FreetypeDone(memory,library,stream);
           ThrowFreetypeErrorException("UnrecognizedFontEncoding",ft_status,
             encoding);
           return(MagickFalse);
@@ -1694,7 +1702,7 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
   if (ft_status != 0)
     {
       (void) FT_Done_Face(face);
-      FreetypeDone(memory,library);
+      FreetypeDone(memory,library,stream);
       ThrowFreetypeErrorException("UnableToReadFont",ft_status,
         draw_info->font);
       return(MagickFalse);
@@ -1733,7 +1741,7 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
       (first_glyph_id == 0))
     {
       (void) FT_Done_Face(face);
-      FreetypeDone(memory,library);
+      FreetypeDone(memory,library,stream);
       return(MagickTrue);
     }
   /*
@@ -2048,7 +2056,7 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
   */
   annotate_info=DestroyDrawInfo(annotate_info);
   (void) FT_Done_Face(face);
-  FreetypeDone(memory,library);
+  FreetypeDone(memory,library,stream);
   return(status);
 }
 #else
