@@ -15,7 +15,7 @@
 %                              Anthony Thyssen                                %
 %                                 April 2011                                  %
 %                                                                             %
-%  Copyright 1999-2021 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright @ 1999 ImageMagick Studio LLC, a non-profit organization         %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -31,7 +31,7 @@
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-% General methds for handling the WandCLI structure used for Command Line.
+% General methods for handling the WandCLI structure used for Command Line.
 %
 % Anthony Thyssen, April 2011
 */
@@ -76,21 +76,8 @@ WandExport MagickCLI *AcquireMagickCLI(ImageInfo *image_info,
   MagickCLI
     *cli_wand;
 
-  /* precaution - as per NewMagickWand() */
-  {
-     size_t depth = MAGICKCORE_QUANTUM_DEPTH;
-     const char *quantum = GetMagickQuantumDepth(&depth);
-     if (depth != MAGICKCORE_QUANTUM_DEPTH)
-       ThrowWandFatalException(WandError,"QuantumDepthMismatch",quantum);
-  }
-
-  /* allocate memory for MgaickCLI */
+  CheckMagickCoreCompatibility();
   cli_wand=(MagickCLI *) AcquireCriticalMemory(sizeof(*cli_wand));
-
-  /* Initialize Wand Part of MagickCLI
-     FUTURE: this is a repeat of code from NewMagickWand()
-     However some parts may be given fro man external source!
-  */
   cli_wand->wand.id=AcquireWandId();
   (void) FormatLocaleString(cli_wand->wand.name,MagickPathExtent,
            "%s-%.20g","MagickWandCLI", (double) cli_wand->wand.id);
@@ -115,7 +102,7 @@ WandExport MagickCLI *AcquireMagickCLI(ImageInfo *image_info,
   cli_wand->image_info_stack=(Stack *) NULL;
 
   /* default exception location...
-     EG: sprintf(locaiton, filename, line, column);
+     EG: sprintf(location, filename, line, column);
   */
   cli_wand->location="from \"%s\"";   /* location format using arguments: */
                                       /*      filename, line, column */
@@ -140,7 +127,7 @@ WandExport MagickCLI *AcquireMagickCLI(ImageInfo *image_info,
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  DestroyMagickCLI() destorys everything in a CLI wand, including image_info
+%  DestroyMagickCLI() destroys everything in a CLI wand, including image_info
 %  and any exceptions, if still present in the wand.
 %
 %  The format of the NewMagickWand method is:
@@ -205,7 +192,7 @@ WandExport MagickCLI *DestroyMagickCLI(MagickCLI *cli_wand)
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  CLICatchException() will report exceptions, either just non-fatal warnings
-%  only, or all errors, according to 'all_execeptions' boolean argument.
+%  only, or all errors, according to 'all_exceptions' boolean argument.
 %
 %  The function returns true if errors are fatal, in which case the caller
 %  should abort and re-call with an 'all_exceptions' argument of true before
@@ -284,9 +271,9 @@ WandExport MagickBooleanType CLILogEvent(MagickCLI *cli_wand,
     return(MagickFalse);
 
   /* HACK - prepend the CLI location to format string.
-     The better way would be add more arguments to to the 'va' oparands
+     The better way would be add more arguments to the 'va' operands
      list, but that does not appear to be possible! So we do some
-     pre-formating of the location info here.
+     pre-formatting of the location info here.
   */
   (void) FormatLocaleString(new_format,MagickPathExtent,cli_wand->location,
        cli_wand->filename, cli_wand->line, cli_wand->column);
@@ -332,9 +319,9 @@ WandExport MagickBooleanType CLIThrowException(MagickCLI *cli_wand,
     operands;
 
   /* HACK - append location to format string.
-     The better way would be add more arguments to to the 'va' oparands
+     The better way would be add more arguments to the 'va' operands
      list, but that does not appear to be possible! So we do some
-     pre-formating of the location info here.
+     pre-formatting of the location info here.
   */
   (void) CopyMagickString(new_format,format,MagickPathExtent);
   (void) ConcatenateMagickString(new_format," ",MagickPathExtent);
