@@ -17,7 +17,7 @@
 %                                 April 2007                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2019 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright @ 2007 ImageMagick Studio LLC, a non-profit organization         %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -61,19 +61,22 @@
 #include "MagickCore/utility.h"
 #if defined(MAGICKCORE_OPENEXR_DELEGATE)
 #include <ImfCRgbaFile.h>
+#if IMF_VERSION_NUMBER > 1
+#include <OpenEXRConfig.h>
+#endif
 
 /*
-  Typedef declaractions.
+  Typedef declarations.
 */
-typedef struct _ExrWindow
+typedef struct _EXRWindowInfo
 {
   int
     max_x,
     max_y,
     min_x,
     min_y;
-} ExrWindow;
-
+} EXRWindowInfo;
+
 /*
   Forward declarations.
 */
@@ -147,33 +150,32 @@ static Image *ReadEXRImage(const ImageInfo *image_info,ExceptionInfo *exception)
   const ImfHeader
     *hdr_info;
 
-  ExrWindow
+  EXRWindowInfo
     data_window,
     display_window;
 
   Image
     *image;
 
-  ImageInfo
-    *read_info;
-
   ImfInputFile
     *file;
 
   ImfRgba
     *scanline;
 
+  int
+    compression;
+
   MagickBooleanType
     status;
 
-  register ssize_t
-    x;
-
-  register Quantum
+  Quantum
     *q;
 
+  size_t
+    columns;
+
   ssize_t
-    columns,
     y;
 
   /*
@@ -181,11 +183,11 @@ static Image *ReadEXRImage(const ImageInfo *image_info,ExceptionInfo *exception)
   */
   assert(image_info != (const ImageInfo *) NULL);
   assert(image_info->signature == MagickCoreSignature);
-  if (image_info->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
-      image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickCoreSignature);
+  if (IsEventLogging() != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      image_info->filename);
   image=AcquireImage(image_info,exception);
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
@@ -193,46 +195,65 @@ static Image *ReadEXRImage(const ImageInfo *image_info,ExceptionInfo *exception)
       image=DestroyImageList(image);
       return((Image *) NULL);
     }
-  read_info=CloneImageInfo(image_info);
-  if (IsPathAccessible(read_info->filename) == MagickFalse)
-    {
-      (void) AcquireUniqueFilename(read_info->filename);
-      (void) ImageToFile(image,read_info->filename,exception);
-    }
-  file=ImfOpenInputFile(read_info->filename);
+  file=ImfOpenInputFile(image->filename);
   if (file == (ImfInputFile *) NULL)
     {
       ThrowFileException(exception,BlobError,"UnableToOpenBlob",
         ImfErrorMessage());
-      if (LocaleCompare(image_info->filename,read_info->filename) != 0)
-        (void) RelinquishUniqueFileResource(read_info->filename);
-      read_info=DestroyImageInfo(read_info);
       image=DestroyImageList(image);
       return((Image *) NULL);
     }
   hdr_info=ImfInputHeader(file);
-  ImfHeaderDisplayWindow(hdr_info,&display_window.min_x,&display_window.min_y,
+  ImfHeaderDataWindow(hdr_info,&display_window.min_x,&display_window.min_y,
     &display_window.max_x,&display_window.max_y);
-  image->columns=display_window.max_x-display_window.min_x+1UL;
-  image->rows=display_window.max_y-display_window.min_y+1UL;
+  image->columns=((size_t) display_window.max_x-display_window.min_x+1UL);
+  image->rows=((size_t) display_window.max_y-display_window.min_y+1UL);
   image->alpha_trait=BlendPixelTrait;
-  SetImageColorspace(image,RGBColorspace,exception);
+  (void) SetImageColorspace(image,RGBColorspace,exception);
   image->gamma=1.0;
+  image->compression=NoCompression;
+  compression=ImfHeaderCompression(hdr_info);
+  if (compression == IMF_RLE_COMPRESSION)
+    image->compression=RLECompression;
+  if (compression == IMF_ZIPS_COMPRESSION)
+    image->compression=ZipSCompression;
+  if (compression == IMF_ZIP_COMPRESSION)
+    image->compression=ZipCompression;
+  if (compression == IMF_PIZ_COMPRESSION)
+    image->compression=PizCompression;
+  if (compression == IMF_PXR24_COMPRESSION)
+    image->compression=Pxr24Compression;
+#if defined(IMF_B44_COMPRESSION)
+  if (compression == IMF_B44_COMPRESSION)
+    image->compression=B44Compression;
+#endif
+#if defined(IMF_B44A_COMPRESSION)
+  if (compression == IMF_B44A_COMPRESSION)
+    image->compression=B44ACompression;
+#endif
+#if defined(IMF_DWAA_COMPRESSION)
+  if (compression == IMF_DWAA_COMPRESSION)
+    image->compression=DWAACompression;
+#endif
+#if defined(IMF_DWAB_COMPRESSION)
+  if (compression == IMF_DWAB_COMPRESSION)
+    image->compression=DWABCompression;
+#endif
   if (image_info->ping != MagickFalse)
     {
       (void) ImfCloseInputFile(file);
-      if (LocaleCompare(image_info->filename,read_info->filename) != 0)
-        (void) RelinquishUniqueFileResource(read_info->filename);
-      read_info=DestroyImageInfo(read_info);
       (void) CloseBlob(image);
       return(GetFirstImageInList(image));
     }
   status=SetImageExtent(image,image->columns,image->rows,exception);
   if (status == MagickFalse)
-    return(DestroyImageList(image));
+    {
+      (void) ImfCloseInputFile(file);
+      return(DestroyImageList(image));
+    }
   ImfHeaderDataWindow(hdr_info,&data_window.min_x,&data_window.min_y,
     &data_window.max_x,&data_window.max_y);
-  columns=(ssize_t) data_window.max_x-data_window.min_x+1UL;
+  columns=((size_t) data_window.max_x-data_window.min_x+1UL);
   if ((display_window.min_x > data_window.max_x) ||
       (display_window.min_x+(int) image->columns <= data_window.min_x))
     scanline=(ImfRgba *) NULL;
@@ -242,9 +263,6 @@ static Image *ReadEXRImage(const ImageInfo *image_info,ExceptionInfo *exception)
       if (scanline == (ImfRgba *) NULL)
         {
           (void) ImfCloseInputFile(file);
-          if (LocaleCompare(image_info->filename,read_info->filename) != 0)
-            (void) RelinquishUniqueFileResource(read_info->filename);
-          read_info=DestroyImageInfo(read_info);
           image=DestroyImageList(image);
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
         }
@@ -254,10 +272,13 @@ static Image *ReadEXRImage(const ImageInfo *image_info,ExceptionInfo *exception)
     int
       yy;
 
+    ssize_t
+      x;
+
     q=QueueAuthenticPixels(image,0,y,image->columns,1,exception);
     if (q == (Quantum *) NULL)
       break;
-    yy=display_window.min_y+y;
+    yy=(int) (display_window.min_y+y);
     if ((yy < data_window.min_y) || (yy > data_window.max_y) ||
         (scanline == (ImfRgba *) NULL))
       {
@@ -270,16 +291,24 @@ static Image *ReadEXRImage(const ImageInfo *image_info,ExceptionInfo *exception)
           break;
         continue;
       }
-    memset(scanline,0,columns*sizeof(*scanline));
-    ImfInputSetFrameBuffer(file,scanline-data_window.min_x-columns*yy,1,
-      columns);
-    ImfInputReadPixels(file,yy,yy);
+    (void) memset(scanline,0,columns*sizeof(*scanline));
+    if (ImfInputSetFrameBuffer(file,scanline-data_window.min_x-columns*yy,1,
+      columns) == 0)
+      {
+        status=MagickFalse;
+        break;
+      }
+    if (ImfInputReadPixels(file,yy,yy) == 0)
+      {
+        status=MagickFalse;
+        break;
+      }
     for (x=0; x < (ssize_t) image->columns; x++)
     {
       int
         xx;
 
-      xx=display_window.min_x+((int) x-data_window.min_x);
+      xx=(int) (display_window.min_x+x-data_window.min_x);
       if ((xx < 0) || (display_window.min_x+(int) x > data_window.max_x))
         SetPixelViaPixelInfo(image,&image->background_color,q);
       else
@@ -300,9 +329,8 @@ static Image *ReadEXRImage(const ImageInfo *image_info,ExceptionInfo *exception)
   }
   scanline=(ImfRgba *) RelinquishMagickMemory(scanline);
   (void) ImfCloseInputFile(file);
-  if (LocaleCompare(image_info->filename,read_info->filename) != 0)
-    (void) RelinquishUniqueFileResource(read_info->filename);
-  read_info=DestroyImageInfo(read_info);
+  if (status == MagickFalse)
+    ThrowReaderException(CorruptImageError,"UnableToReadImageData");
   (void) CloseBlob(image);
   return(GetFirstImageInList(image));
 }
@@ -333,15 +361,25 @@ static Image *ReadEXRImage(const ImageInfo *image_info,ExceptionInfo *exception)
 */
 ModuleExport size_t RegisterEXRImage(void)
 {
+  char
+    version[MagickPathExtent];
+
   MagickInfo
     *entry;
 
+  *version='\0';
   entry=AcquireMagickInfo("EXR","EXR","High Dynamic-range (HDR)");
 #if defined(MAGICKCORE_OPENEXR_DELEGATE)
   entry->decoder=(DecodeImageHandler *) ReadEXRImage;
   entry->encoder=(EncodeImageHandler *) WriteEXRImage;
+#if defined( OPENEXR_PACKAGE_STRING)
+  (void) FormatLocaleString(version,MagickPathExtent,OPENEXR_PACKAGE_STRING);
+#endif
 #endif
   entry->magick=(IsImageFormatHandler *) IsEXR;
+  if (*version != '\0')
+    entry->version=ConstantString(version);
+  entry->flags|=CoderDecoderSeekableStreamFlag;
   entry->flags^=CoderAdjoinFlag;
   entry->flags^=CoderBlobSupportFlag;
   (void) RegisterMagickInfo(entry);
@@ -431,10 +469,10 @@ static MagickBooleanType WriteEXRImage(const ImageInfo *image_info,Image *image,
   MagickBooleanType
     status;
 
-  register const Quantum
+  const Quantum
     *p;
 
-  register ssize_t
+  ssize_t
     x;
 
   ssize_t
@@ -447,10 +485,10 @@ static MagickBooleanType WriteEXRImage(const ImageInfo *image_info,Image *image,
   assert(image_info->signature == MagickCoreSignature);
   assert(image != (Image *) NULL);
   assert(image->signature == MagickCoreSignature);
-  if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickCoreSignature);
+  if (IsEventLogging() != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,exception);
   if (status == MagickFalse)
     return(status);
@@ -463,6 +501,8 @@ static MagickBooleanType WriteEXRImage(const ImageInfo *image_info,Image *image,
   ImfHeaderSetDisplayWindow(hdr_info,0,0,(int) image->columns-1,(int)
     image->rows-1);
   compression=IMF_NO_COMPRESSION;
+  if (write_info->compression == RLECompression)
+    compression=IMF_RLE_COMPRESSION;
   if (write_info->compression == ZipSCompression)
     compression=IMF_ZIPS_COMPRESSION;
   if (write_info->compression == ZipCompression)
@@ -471,13 +511,21 @@ static MagickBooleanType WriteEXRImage(const ImageInfo *image_info,Image *image,
     compression=IMF_PIZ_COMPRESSION;
   if (write_info->compression == Pxr24Compression)
     compression=IMF_PXR24_COMPRESSION;
-#if defined(B44Compression)
+#if defined(IMF_B44_COMPRESSION)
   if (write_info->compression == B44Compression)
     compression=IMF_B44_COMPRESSION;
 #endif
-#if defined(B44ACompression)
+#if defined(IMF_B44A_COMPRESSION)
   if (write_info->compression == B44ACompression)
     compression=IMF_B44A_COMPRESSION;
+#endif
+#if defined(IMF_DWAA_COMPRESSION)
+  if (write_info->compression == DWAACompression)
+    compression=IMF_DWAA_COMPRESSION;
+#endif
+#if defined(IMF_DWAB_COMPRESSION)
+  if (write_info->compression == DWABCompression)
+    compression=IMF_DWAB_COMPRESSION;
 #endif
   channels=0;
   value=GetImageOption(image_info,"exr:color-type");
