@@ -513,11 +513,11 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
   */
   assert(image_info != (const ImageInfo *) NULL);
   assert(image_info->signature == MagickCoreSignature);
-  if (image_info->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
-      image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickCoreSignature);
+  if (IsEventLogging() != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      image_info->filename);
   image=AcquireImage(image_info,exception);
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
@@ -709,6 +709,12 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
               case 'c':
               case 'C':
               {
+                if (LocaleCompare(keyword,"channel-mask") == 0)
+                  {
+                    image->channel_mask=(ChannelType)
+                      StringToUnsignedLong(options);
+                    break;
+                  }
                 if (LocaleCompare(keyword,"class") == 0)
                   {
                     ssize_t
@@ -738,6 +744,11 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
                     image->colorspace=(ColorspaceType) colorspace;
                     break;
                   }
+                if (LocaleCompare(keyword,"columns") == 0)
+                  {
+                    image->columns=StringToUnsignedLong(options);
+                    break;
+                  }
                 if (LocaleCompare(keyword,"compression") == 0)
                   {
                     ssize_t
@@ -750,11 +761,6 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
                     image->compression=(CompressionType) compression;
                     break;
                   }
-                if (LocaleCompare(keyword,"columns") == 0)
-                  {
-                    image->columns=StringToUnsignedLong(options);
-                    break;
-                  }
                 (void) SetImageProperty(image,keyword,options,exception);
                 break;
               }
@@ -843,8 +849,11 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
                 if (LocaleCompare(keyword,"id") == 0)
                   {
                     if (*id != '\0')
-                      ThrowMIFFException(CorruptImageError,
-                        "ImproperImageHeader");
+                      {
+                        options=DestroyString(options);
+                        ThrowMIFFException(CorruptImageError,
+                          "ImproperImageHeader");
+                      }
                     (void) CopyMagickString(id,options,MagickPathExtent);
                     break;
                   }
@@ -886,6 +895,21 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
                 (void) SetImageProperty(image,keyword,options,exception);
                 break;
               }
+              case 'n':
+              case 'N':
+              {
+                if (LocaleCompare(keyword,"number-channels") == 0)
+                  {
+                    image->number_channels=StringToUnsignedLong(options);
+                    break;
+                  }
+                if (LocaleCompare(keyword,"number-meta-channels") == 0)
+                  {
+                    image->number_meta_channels=StringToUnsignedLong(options);
+                    break;
+                  }
+                break;
+              }
               case 'o':
               case 'O':
               {
@@ -1117,6 +1141,8 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
         (image->compression == UndefinedCompression) ||
         (image->colorspace == UndefinedColorspace) ||
         (image->columns == 0) || (image->rows == 0) ||
+        (image->number_meta_channels > (size_t) (MaxPixelChannels-MetaPixelChannels)) ||
+        ((image->number_channels+image->number_meta_channels) >= MaxPixelChannels) ||
         (image->depth == 0) || (image->depth > 64))
       {
         if (profiles != (LinkedListInfo *) NULL)
@@ -1314,15 +1340,15 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
         if (status == MagickFalse)
           ThrowMIFFException(ResourceLimitError,"MemoryAllocationFailed");
       }
-    packet_size=(size_t) (quantum_info->depth/8);
+    packet_size=(size_t) (image->depth/8);
     if (image->storage_class == DirectClass)
-      packet_size=(size_t) (3*quantum_info->depth/8);
+      packet_size=(size_t) (3*image->depth/8);
     if (IsGrayColorspace(image->colorspace) != MagickFalse)
-      packet_size=quantum_info->depth/8;
+      packet_size=image->depth/8;
     if (image->alpha_trait != UndefinedPixelTrait)
-      packet_size+=quantum_info->depth/8;
+      packet_size+=image->depth/8;
     if (image->colorspace == CMYKColorspace)
-      packet_size+=quantum_info->depth/8;
+      packet_size+=image->depth/8;
     if (image->compression == RLECompression)
       packet_size++;
     compress_extent=MagickMax(MagickMax(BZipMaxExtent(packet_size*
@@ -1358,6 +1384,8 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
         if (image->alpha_trait != UndefinedPixelTrait)
           quantum_type=IndexAlphaQuantum;
       }
+    if (image->number_meta_channels != 0)
+      quantum_type=MultispectralQuantum;
     status=MagickTrue;
     GetPixelInfo(image,&pixel);
 #if defined(MAGICKCORE_BZLIB_DELEGATE)
@@ -2036,15 +2064,13 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
   QuantumType
     quantum_type;
 
-  ssize_t
-    i;
-
   size_t
-    imageListLength,
     length,
+    number_scenes,
     packet_size;
 
   ssize_t
+    i,
     y;
 
   unsigned char
@@ -2064,15 +2090,15 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
   assert(image_info->signature == MagickCoreSignature);
   assert(image != (Image *) NULL);
   assert(image->signature == MagickCoreSignature);
-  if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickCoreSignature);
+  if (IsEventLogging() != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,exception);
   if (status == MagickFalse)
     return(status);
   scene=0;
-  imageListLength=GetImageListLength(image);
+  number_scenes=GetImageListLength(image);
   do
   {
     /*
@@ -2124,15 +2150,15 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
       default:
         break;
     }
-    packet_size=(size_t) (quantum_info->depth/8);
+    packet_size=(size_t) (image->depth/8);
     if (image->storage_class == DirectClass)
-      packet_size=(size_t) (3*quantum_info->depth/8);
+      packet_size=(size_t) (3*image->depth/8);
     if (IsGrayColorspace(image->colorspace) != MagickFalse)
-      packet_size=(size_t) (quantum_info->depth/8);
+      packet_size=(size_t) (image->depth/8);
     if (image->alpha_trait != UndefinedPixelTrait)
-      packet_size+=quantum_info->depth/8;
+      packet_size+=image->depth/8;
     if (image->colorspace == CMYKColorspace)
-      packet_size+=quantum_info->depth/8;
+      packet_size+=image->depth/8;
     if (compression == RLECompression)
       packet_size++;
     length=MagickMax(BZipMaxExtent(packet_size*image->columns),ZipMaxExtent(
@@ -2147,17 +2173,22 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
     /*
       Write MIFF header.
     */
-    (void) WriteBlobString(image,"id=ImageMagick  version=1.0\n");
+    (void) WriteBlobString(image,"id=ImageMagick version=1.0\n");
     (void) FormatLocaleString(buffer,MagickPathExtent,
-      "class=%s  colors=%.20g  alpha-trait=%s\n",CommandOptionToMnemonic(
+      "class=%s colors=%.20g alpha-trait=%s\n",CommandOptionToMnemonic(
       MagickClassOptions,image->storage_class),(double) image->colors,
       CommandOptionToMnemonic(MagickPixelTraitOptions,(ssize_t)
       image->alpha_trait));
     (void) WriteBlobString(image,buffer);
+    (void) FormatLocaleString(buffer,MagickPathExtent,
+      "number-channels=%.20g number-meta-channels=%.20g channel-mask=%.20g\n",
+      (double) image->number_channels,(double) image->number_meta_channels,
+      (double) image->channel_mask);
+    (void) WriteBlobString(image,buffer);
     if (image->alpha_trait != UndefinedPixelTrait)
       (void) WriteBlobString(image,"matte=True\n");
     (void) FormatLocaleString(buffer,MagickPathExtent,
-      "columns=%.20g  rows=%.20g  depth=%.20g\n",(double) image->columns,
+      "columns=%.20g rows=%.20g depth=%.20g\n",(double) image->columns,
       (double) image->rows,(double) image->depth);
     (void) WriteBlobString(image,buffer);
     if (image->type != UndefinedType)
@@ -2229,12 +2260,12 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
         (GetPreviousImageInList(image) != (Image *) NULL))
       {
         if (image->scene == 0)
-          (void) FormatLocaleString(buffer,MagickPathExtent,"iterations=%.20g  "
-            "delay=%.20g  ticks-per-second=%.20g\n",(double) image->iterations,
+          (void) FormatLocaleString(buffer,MagickPathExtent,"iterations=%.20g "
+            "delay=%.20g ticks-per-second=%.20g\n",(double) image->iterations,
             (double) image->delay,(double) image->ticks_per_second);
         else
           (void) FormatLocaleString(buffer,MagickPathExtent,"scene=%.20g  "
-            "iterations=%.20g  delay=%.20g  ticks-per-second=%.20g\n",(double)
+            "iterations=%.20g delay=%.20g ticks-per-second=%.20g\n",(double)
             image->scene,(double) image->iterations,(double) image->delay,
             (double) image->ticks_per_second);
         (void) WriteBlobString(image,buffer);
@@ -2294,10 +2325,10 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
     if (image->chromaticity.white_point.x != 0.0)
       {
         /*
-          Note chomaticity points.
+          Note chromaticity points.
         */
-        (void) FormatLocaleString(buffer,MagickPathExtent,"red-primary=%g,"
-          "%g  green-primary=%g,%g  blue-primary=%g,%g\n",
+        (void) FormatLocaleString(buffer,MagickPathExtent,"red-primary=%g,%g "
+          "green-primary=%g,%g blue-primary=%g,%g\n",
           image->chromaticity.red_primary.x,image->chromaticity.red_primary.y,
           image->chromaticity.green_primary.x,
           image->chromaticity.green_primary.y,
@@ -2427,7 +2458,7 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
         /*
           Allocate colormap.
         */
-        colormap_size=(size_t) (3*quantum_info->depth/8);
+        colormap_size=(size_t) (3*image->depth/8);
         colormap=(unsigned char *) AcquireQuantumMemory(image->colors,
           colormap_size*sizeof(*colormap));
         if (colormap == (unsigned char *) NULL)
@@ -2438,7 +2469,7 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
         q=colormap;
         for (i=0; i < (ssize_t) image->colors; i++)
         {
-          switch (quantum_info->depth)
+          switch (image->depth)
           {
             case 32:
             default:
@@ -2564,10 +2595,12 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
         *magick_restrict p;
 
       ssize_t
+        count,
         x;
 
       if (status == MagickFalse)
         break;
+      count=0;
       p=GetVirtualPixels(image,0,y,image->columns,1,exception);
       if (p == (const Quantum *) NULL)
         break;
@@ -2593,10 +2626,11 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
             if (code < 0)
               status=MagickFalse;
             length=(size_t) (bzip_info.next_out-(char *) compress_pixels);
+            count=0;
             if (length != 0)
               {
                 (void) WriteBlobMSBLong(image,(unsigned int) length);
-                (void) WriteBlob(image,length,compress_pixels);
+                count=WriteBlob(image,length,compress_pixels);
               }
           } while (bzip_info.avail_in != 0);
           break;
@@ -2620,10 +2654,11 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
             if (code != LZMA_OK)
               status=MagickFalse;
             length=(size_t) (lzma_info.next_out-compress_pixels);
+            count=0;
             if (length != 0)
               {
                 (void) WriteBlobMSBLong(image,(unsigned int) length);
-                (void) WriteBlob(image,length,compress_pixels);
+                count=WriteBlob(image,length,compress_pixels);
               }
           } while (lzma_info.avail_in != 0);
           break;
@@ -2648,10 +2683,11 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
             if (code != Z_OK)
               status=MagickFalse;
             length=(size_t) (zip_info.next_out-compress_pixels);
+            count=0;
             if (length != 0)
               {
                 (void) WriteBlobMSBLong(image,(unsigned int) length);
-                (void) WriteBlob(image,length,compress_pixels);
+                count=WriteBlob(image,length,compress_pixels);
               }
           } while (zip_info.avail_in != 0);
           break;
@@ -2677,17 +2713,24 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
             p+=GetPixelChannels(image);
           }
           q=PopRunlengthPacket(image,q,length,&pixel);
-          (void) WriteBlob(image,(size_t) (q-pixels),pixels);
+          length=(size_t) (q-pixels);
+          count=WriteBlob(image,length,pixels);
           break;
         }
         default:
         {
           (void) ExportQuantumPixels(image,(CacheView *) NULL,quantum_info,
             quantum_type,pixels,exception);
-          (void) WriteBlob(image,packet_size*image->columns,pixels);
+          length=packet_size*image->columns;
+          count=WriteBlob(image,length,pixels);
           break;
         }
       }
+      if (length != (size_t) count)
+        {
+          status=MagickFalse;
+          break;
+        }
       if (image->previous == (Image *) NULL)
         {
           status=SetImageProgress(image,SaveImageTag,(MagickOffsetType) y,
@@ -2790,7 +2833,7 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
     if (GetNextImageInList(image) == (Image *) NULL)
       break;
     image=SyncNextImageInList(image);
-    status=SetImageProgress(image,SaveImagesTag,scene++,imageListLength);
+    status=SetImageProgress(image,SaveImagesTag,scene++,number_scenes);
     if (status == MagickFalse)
       break;
   } while (image_info->adjoin != MagickFalse);
